Package: shiny2docker
Title: Generate Dockerfiles for 'Shiny' Applications
Version: 0.0.4
Authors@R: 
    person("Vincent", "Guyader", , "vincent@thinkr.fr", role = c("aut", "cre"),
           comment = c(ORCID = "0000-0003-0671-9270"))
Description: Automates the creation of Dockerfiles for deploying 'Shiny'
    applications.  By integrating with 'renv' for dependency management
    and leveraging Docker-based solutions, it simplifies the process of
    containerizing 'Shiny' apps, ensuring reproducibility and consistency
    across different environments.  Additionally, it facilitates the setup
    of CI/CD pipelines for building Docker images on both GitLab and
    GitHub.
License: MIT + file LICENSE
URL: https://github.com/VincentGuyader/shiny2docker
BugReports: https://github.com/VincentGuyader/shiny2docker/issues
Imports: attachment (>= 0.4.3), cli, dockerfiler (>= 0.2.6), here,
        yesno
Suggests: knitr, mockery, renv, rmarkdown, rstudioapi, shiny, testthat
        (>= 3.0.0)
VignetteBuilder: knitr
Config/testthat/edition: 3
Encoding: UTF-8
RoxygenNote: 7.3.3
NeedsCompilation: no
Packaged: 2026-05-15 15:53:49 UTC; PC
Author: Vincent Guyader [aut, cre] (ORCID:
    <https://orcid.org/0000-0003-0671-9270>)
Maintainer: Vincent Guyader <vincent@thinkr.fr>
Repository: CRAN
Date/Publication: 2026-05-15 20:30:02 UTC
Built: R 4.5.2; ; 2026-05-15 22:53:14 UTC; unix
